@@ -30,15 +30,18 @@ SGD<UpdatePolicyType, DecayPolicyType>::SGD(
     const bool shuffle,
     const UpdatePolicyType& updatePolicy,
     const DecayPolicyType& decayPolicy,
-    const bool resetPolicy) :
+    const bool resetPolicy,
+    const bool exactObjective) :
     stepSize(stepSize),
     batchSize(batchSize),
     maxIterations(maxIterations),
     tolerance(tolerance),
     shuffle(shuffle),
+    exactObjective(exactObjective),
     updatePolicy(updatePolicy),
     decayPolicy(decayPolicy),
-    resetPolicy(resetPolicy)
+    resetPolicy(resetPolicy),
+    isInitialized(false)
 { /* Nothing to do. */ }
 
 //! Optimize the function (minimize).
@@ -63,8 +66,11 @@ double SGD<UpdatePolicyType, DecayPolicyType>::Optimize(
   double lastObjective = DBL_MAX;
 
   // Initialize the update policy.
-  if (resetPolicy)
+  if (resetPolicy || !isInitialized)
+  {
     updatePolicy.Initialize(iterate.n_rows, iterate.n_cols);
+    isInitialized = true;
+  }
 
   // Now iterate!
   arma::mat gradient(iterate.n_rows, iterate.n_cols);
@@ -130,12 +136,15 @@ double SGD<UpdatePolicyType, DecayPolicyType>::Optimize(
   Info << "SGD: maximum iterations (" << maxIterations << ") reached; "
       << "terminating optimization." << std::endl;
 
-  // Calculate final objective.
-  overallObjective = 0;
-  for (size_t i = 0; i < numFunctions; i += batchSize)
+  // Calculate final objective if exactObjective is set to true.
+  if (exactObjective)
   {
-    const size_t effectiveBatchSize = std::min(batchSize, numFunctions - i);
-    overallObjective += f.Evaluate(iterate, i, effectiveBatchSize);
+    overallObjective = 0;
+    for (size_t i = 0; i < numFunctions; i += batchSize)
+    {
+      const size_t effectiveBatchSize = std::min(batchSize, numFunctions - i);
+      overallObjective += f.Evaluate(iterate, i, effectiveBatchSize);
+    }
   }
   return overallObjective;
 }
